==> ckeditor_4.4.4+dfsg1.orig.tar.xz: ckeditor-dev-4.4.4/plugins/forms/lang/ru.js <==
﻿/*
Copyright (c) 2003-2014, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or http://ckeditor.com/license
*/
CKEDITOR.plugins.setLang( 'forms', 'ru', {
	button: {
		title: 'Свойства кнопки',
		text: 'Текст (Значение)',
		type: 'Тип',
		typeBtn: 'Кнопка',
		typeSbm: 'Отправка',
		typeRst: 'Сброс'
	},
	checkboxAndRadio: {
		checkboxTitle: 'Свойства флаговой кнопки',
		radioTitle: 'Свойства кнопки выбора',
		value: 'Значение',
		selected: 'Выбрано'
	},
	form: {
		title: 'Свойства формы',
		menu: 'Свойства формы',
		action: 'Действие',
		method: 'Метод',
		encoding: 'Кодировка'
	},
	hidden: {
		title: 'Свойства скрытого поля',
		name: 'Имя',
		value: 'Значение'
	},
	select: {
		title: 'Свойства списка выбора',
		selectInfo: 'Информация о списке выбора',
		opAvail: 'Доступные варианты',
		value: 'Значение',
		size: 'Размер',
		lines: 'строк(и)',
		chkMulti: 'Разрешить выбор нескольких вариантов',
		opText: 'Текст',
		opValue: 'Значение',
		btnAdd: 'Добавить',
		btnModify: 'Изменить',
		btnUp: 'Поднять',
		btnDown: 'Опустить',
		btnSetValue: 'Пометить как выбранное',
		btnDelete: 'Удалить'
	},
	textarea: {
		title: 'Свойства многострочного текстового поля',
		cols: 'Колонок',
		rows: 'Строк'
	},
	textfield: {
		title: 'Свойства текстового поля',
		name: 'Имя',
		value: 'Значение',
		charWidth: 'Ширина поля (в символах)',
		maxChars: 'Макс. количество символов',
		type: 'Тип содержимого',
		typeText: 'Текст',
		typePass: 'Пароль',
		typeEmail: 'Email',
		typeSearch: 'Поиск',
		typeTel: 'Номер телефона',
		typeUrl: 'Ссылка'
	}
} );

==> ckeditor_4.5.6+dfsg.orig.tar.xz: ckeditor-dev-4.5.6/plugins/forms/lang/ru.js <==
﻿/*
Copyright (c) 2003-2015, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or http://ckeditor.com/license
*/
CKEDITOR.plugins.setLang( 'forms', 'ru', {
	button: {
		title: 'Свойства кнопки',
		text: 'Текст (Значение)',
		type: 'Тип',
		typeBtn: 'Кнопка',
		typeSbm: 'Отправка',
		typeRst: 'Сброс'
	},
	checkboxAndRadio: {
		checkboxTitle: 'Свойства флаговой кнопки',
		radioTitle: 'Свойства кнопки выбора',
		value: 'Значение',
		selected: 'Выбрано',
		required: 'Обязательное поле'
	},
	form: {
		title: 'Свойства формы',
		menu: 'Свойства формы',
		action: 'Действие',
		method: 'Метод',
		encoding: 'Кодировка'
	},
	hidden: {
		title: 'Свойства скрытого поля',
		name: 'Имя',
		value: 'Значение'
	},
	select: {
		title: 'Свойства списка выбора',
		selectInfo: 'Информация о списке выбора',
		opAvail: 'Доступные варианты',
		value: 'Значение',
		size: 'Размер',
		lines: 'строк(и)',
		chkMulti: 'Разрешить выбор нескольких вариантов',
		required: 'Обязательное поле',
		opText: 'Текст',
		opValue: 'Значение',
		btnAdd: 'Добавить',
		btnModify: 'Изменить',
		btnUp: 'Поднять',
		btnDown: 'Опустить',
		btnSetValue: 'Пометить как выбранное',
		btnDelete: 'Удалить'
	},
	textarea: {
		title: 'Свойства многострочного текстового поля',
		cols: 'Колонок',
		rows: 'Строк'
	},
	textfield: {
		title: 'Свойства текстового поля',
		name: 'Имя',
		value: 'Значение',
		charWidth: 'Ширина поля (в символах)',
		maxChars: 'Макс. количество символов',
		required: 'Обязательное поле',
		type: 'Тип содержимого',
		typeText: 'Текст',
		typePass: 'Пароль',
		typeEmail: 'Email',
		typeSearch: 'Поиск',
		typeTel: 'Номер телефона',
		typeUrl: 'Ссылка'
	}
} );
